@CHARSET "ISO-8859-1";


/* ----- Strip Panel ------- */

.ug-videoskin-bottom-text .ug-strip-panel{
	background-color:#232323;
}

/* ----- Thumb Wrapper ------- */

.ug-videoskin-bottom-text .ug-thumb-wrapper{
	background-color:#232323;
	border-bottom:1px solid #393939;
	width:200px;
	height:80px;
	cursor:pointer;
  	text-align:left;
}


.ug-videoskin-bottom-text .ug-thumb-wrapper:last-child{
	border-bottom:none;
}

/* - thumb selected and over - */

.ug-videoskin-bottom-text .ug-thumb-wrapper.ug-thumb-over{
	cursor:pointer;
	background-color:#1A1A1A;
}

.ug-videoskin-bottom-text .ug-thumb-wrapper.ug-thumb-selected{
	cursor:default;
	background-color:#176DB3;
}

/* ----- Thumb Inner data ------- */

.ug-videoskin-bottom-text .ug-thumb-inner{
	padding-top:15px;
	padding-left:15px;
	padding-right:5px;
}

.ug-videoskin-bottom-text .ug-thumb-title{
	color:white;
	font-size:14px;
  	height:18px;
  	overflow:hidden;
	line-height:normal;	
}

.ug-videoskin-bottom-text .ug-thumb-desc{
	color:#dddddd;
	font-size:11px;
	line-height:normal;
	padding-top:5px;
}

