@CHARSET "ISO-8859-1";

/* ----- Strip Panel ------- */

.ug-videoskin-right-thumb .ug-strip-panel{
	background-color:#232323;
}

/* ----- Thumb Wrapper ------- */

.ug-videoskin-right-thumb .ug-thumb-wrapper{
	background-color:#232323;
	border-bottom:1px solid #393939;
	width:420px;
	height:61px;
	cursor:pointer; 
    text-align:left;
}

.ug-videoskin-right-thumb .ug-thumb-wrapper:last-child{
	border-bottom:none;
}

/* - thumb selected and over - */

.ug-videoskin-right-thumb .ug-thumb-wrapper.ug-thumb-over{
	cursor:pointer;
	background-color:#1A1A1A;
}

.ug-videoskin-right-thumb .ug-thumb-wrapper.ug-thumb-selected{
	cursor:default;
	background-color:#525252;
}

/* ----- Thumb Inner data ------- */


.ug-videoskin-right-thumb .ug-thumb-icon{
	width:72px;
	height:40px;
	float:left;
	background-position:center center;
	background-size:cover;
}

.ug-videoskin-right-thumb .ug-thumb-selected .ug-thumb-icon{
	border:2px solid red;
	box-sizing: border-box;
}

.ug-videoskin-right-thumb .ug-thumb-right{
	float:left;
	padding-left:15px;
}


.ug-videoskin-right-thumb .ug-thumb-inner{
	padding-top:12px;
	padding-left:13px;
	padding-right:5px;
}

.ug-videoskin-right-thumb .ug-thumb-title{
	color:white;
	font-size:16px;
	overflow:hidden;
 	width:300px;
  	height:20px;
	line-height:normal;
}

.ug-videoskin-right-thumb .ug-thumb-desc{
	color:#999999;
	font-size:11px;
    width:300px;
	line-height:normal;
}

/* ----- Under 960 ------- */
.ug-under-960.ug-videoskin-right-thumb .ug-thumb-wrapper
{
  width:320px;
}

.ug-under-960.ug-videoskin-right-thumb .ug-thumb-title {
    width: 206px;
    height:18px;
  	font-size:14px;
}
.ug-under-960.ug-videoskin-right-thumb .ug-thumb-desc
{
  width:167px;
  padding-top:0px;
  line-height:normal;
}


/* ----- Under 780 ------- */

.ug-under-780.ug-videoskin-right-thumb .ug-thumb-wrapper
{
  width:240px;
}

.ug-under-780.ug-videoskin-right-thumb .ug-thumb-icon
{
  width:40px;
}

.ug-under-780.ug-videoskin-right-thumb .ug-thumb-title {
    width: 167px;
    height:18px;
  	font-size:14px;
}

.ug-under-780.ug-videoskin-right-thumb .ug-thumb-desc
{
  width:167px;
  padding-top:0px;
  line-height:normal;
}


/* ----- Under 480 ------- */

.ug-under-480.ug-videoskin-right-thumb .ug-thumb-wrapper
{
  width:56px;
}

.ug-under-480.ug-videoskin-right-thumb .ug-thumb-title {
  display:none;
}

.ug-under-480.ug-videoskin-right-thumb .ug-thumb-desc
{
  display:none;
}

.ug-under-480.ug-videoskin-right-thumb .ug-thumb-inner {
    padding-left: 8px;
    padding-right: 5px;
    padding-top: 12px;
}
      
.ug-under-480.ug-videoskin-right-thumb .ug-thumb-icon
{
  width:40px;
}