@CHARSET "ISO-8859-1";

/* ----- Strip Panel ------- */

.ug-videoskin-right-title-only .ug-strip-panel{
	background-color:#232323;
}

/* ----- Thumb Wrapper ------- */

.ug-videoskin-right-title-only .ug-thumb-wrapper{
	background-color:#232323;
	border-bottom:1px solid #393939;
	width:360px;
	height:60px;
	cursor:pointer;
  	text-align:left;
}


.ug-videoskin-right-title-only .ug-thumb-wrapper:last-child{
	border-bottom:none;
}

/* - thumb selected and over - */

.ug-videoskin-right-title-only .ug-thumb-wrapper.ug-thumb-over{
	cursor:pointer;
	background-color:#1A1A1A;
}

.ug-videoskin-right-title-only .ug-thumb-wrapper.ug-thumb-selected{
	cursor:default;
	background-color:#176DB3;
}

/* ----- Thumb Inner data ------- */

.ug-videoskin-right-title-only .ug-thumb-inner{
	padding-top:18px;
	padding-left:20px;
	padding-right:10px;
}

.ug-videoskin-right-title-only .ug-thumb-title{
	color:white;
	font-size:14px;
	line-height:normal;
}


/* ----- Buttons Panel ------- */

.ug-videoskin-right-title-only .ug-video-buttons-panel{
	height:42px;
	background-color:#000;
	position:absolute;
	display:none;
}

.ug-videoskin-right-title-only .ug-button-prev-video{
	width:50%;
	height:42px;
	float:left;
	background-image:url('images/arrow_left.png');
	cursor:pointer;
	background-repeat:no-repeat;
	background-position:center;
	box-sizing:border-box;
	border-right:1px solid #444;
}

.ug-videoskin-right-title-only .ug-button-prev-video:hover, .ug-videoskin-right-title-only .ug-button-next-video:hover
{
	background-color:#444;
}

.ug-videoskin-right-title-only .ug-button-next-video{
	width:50%;
	height:42px;
	float:right;
	background-image:url('images/arrow_right.png');
	cursor:pointer;
	background-repeat:no-repeat;
	background-position:center;
}



/* ----- Under 960 ------- */
.ug-under-960.ug-videoskin-right-title-only .ug-thumb-wrapper
{
  width:300px;
}

.ug-under-960.ug-videoskin-right-title-only .ug-thumb-title {
    width: 289px;
    height:18px;
  	font-size:14px;
	line-height:normal;
}


.ug-under-960.ug-videoskin-right-title-only .ug-video-buttons-panel{
	display:none;
}

/* ----- Under 780 ------- */

.ug-under-780.ug-videoskin-right-title-only .ug-thumb-wrapper
{
  width:240px;
}

.ug-under-780.ug-videoskin-right-title-only .ug-thumb-icon
{
  width:40px;
}

.ug-under-780.ug-videoskin-right-title-only .ug-thumb-title {
    width: 167px;
    height:18px;
  	font-size:14px;
}


.ug-under-780.ug-videoskin-right-title-only .ug-video-buttons-panel{
	display:none;
}


/* ----- Under 480 ------- */

.ug-under-480.ug-videoskin-right-title-only .ug-thumb-wrapper
{
  width:0px;
}

.ug-under-480.ug-videoskin-right-title-only .ug-thumb-title {
  display:none;
}


.ug-under-480.ug-videoskin-right-title-only .ug-thumb-inner {
    padding-left: 8px;
    padding-right: 5px;
    padding-top: 12px;
}
      
.ug-under-480.ug-videoskin-right-title-only .ug-thumb-icon
{
  width:40px;
}

.ug-under-480.ug-videoskin-right-title-only .ug-video-buttons-panel{
	display:block;
}
