
/*------ Unite Gallery Alexis Skin -------*/


.---------Slider_Arrows--------{}

.ug-arrow-left.ug-skin-alexis,
.ug-arrow-right.ug-skin-alexis{
	width:35px;
	height:35px;
	background-image:url('images/slider_arrow_left.png');
	background-position:0px 0px;
}

.ug-arrow-right.ug-skin-alexis{
	background-image:url('images/slider_arrow_right.png');
}

.ug-arrow-left.ug-skin-alexis.ug-arrow-hover,
.ug-arrow-right.ug-skin-alexis.ug-arrow-hover{
	background-position:0px -35px;
}

.ug-arrow-left.ug-skin-alexis.ug-arrow-disabled,
.ug-arrow-right.ug-skin-alexis.ug-arrow-disabled{
	background-position:0px -70px;
}


.---------Slider_Bullets--------{}

.ug-bullets.ug-skin-alexis .ug-bullet{
	width:28px;
	height:28px;
	background-image:url('images/slider_bullets.png');
	background-position:top left;
	margin-left:5px;
}

.ug-bullets.ug-skin-alexis .ug-bullet.ug-bullet-active{
	background-position:bottom left;
}


.---------Slider_Buttons--------{}

/* --- play button -- */
.ug-button-play.ug-skin-alexis{
	position:absolute;
	background-image:url('images/button_playpause.png');
    width:35px;
    height:35px;
    cursor:pointer;
	background-position:0px 0px;
}

.ug-button-play.ug-skin-alexis.ug-button-hover{
	background-position:0px -35px;	
}

.ug-button-play.ug-skin-alexis.ug-stop-mode{
	background-position:0px -70px;
}

.ug-button-play.ug-skin-alexis.ug-stop-mode.ug-button-hover{
	background-position:0px -105px;
}

/* --- fullscreen button -- */

.ug-button-fullscreen.ug-skin-alexis{
	position:absolute;
	background-image:url('images/button_fullscreen.png');
    width:35px;
    height:35px;
    cursor:pointer;
	background-position:0px 0px;
}

.ug-button-fullscreen.ug-skin-alexis.ug-button-hover{
	background-position:0px -35px;
}

.ug-button-fullscreen.ug-skin-alexis.ug-fullscreenmode{
	background-position:0px -70px;
}

.ug-button-fullscreen.ug-skin-alexis.ug-fullscreenmode.ug-button-hover{
	background-position:0px -105px;
}


.---------Zoom_Panel--------{}

/* --- zoom panel --- */

.ug-zoompanel.ug-skin-alexis .ug-zoompanel-button{
    background-repeat: no-repeat;
    cursor:pointer;
    height: 35px;
    width: 35px;
    margin-top:5px;
    background-position: 0px 0px;	
}

.ug-zoompanel.ug-skin-alexis .ug-zoompanel-plus{
	margin-top:0px;
}

.ug-zoompanel.ug-skin-alexis .ug-zoompanel-plus{
	background-image:url('images/button_zoom_plus.png');
}

.ug-zoompanel.ug-skin-alexis .ug-zoompanel-minus{
	background-image:url('images/button_zoom_minus.png');
}

.ug-zoompanel.ug-skin-alexis .ug-zoompanel-return{
	background-image:url('images/button_zoom_back.png');
}

.ug-zoompanel.ug-skin-alexis .ug-zoompanel-button.ug-button-hover{
    background-position: 0px -35px;
}

.ug-zoompanel.ug-skin-alexis .ug-zoompanel-button-disabled,
.ug-zoompanel.ug-skin-alexis .ug-zoompanel-button.ug-button-hover.ug-zoompanel-button-disabled{
    background-position: 0px -70px;
    cursor:default;
}


.---------Grid_Panel_Arrows--------{}

/*--- down arrow ---*/

.ug-gallery-wrapper .ug-grid-panel .grid-arrow-down.ug-skin-alexis{
	width:40px;
	height:25px;
	background-position:0px -0px;	
	background-image:url('images/grid_arrow_down.png');
}

.ug-gallery-wrapper .ug-grid-panel .grid-arrow-down.ug-skin-alexis.ug-button-hover{
	background-position:0px -25px;
}

.ug-gallery-wrapper .ug-grid-panel .grid-arrow-down.ug-skin-alexis.ug-button-hover.ug-button-disabled,
.ug-gallery-wrapper .ug-grid-panel .grid-arrow-down.ug-skin-alexis.ug-button-disabled{
	background-position:0px -50px;
}


/*--- up arrow ---*/

.ug-gallery-wrapper .ug-grid-panel .grid-arrow-up.ug-skin-alexis{
	width:40px;
	height:25px;
	background-position:0px 0px;
	background-image:url('images/grid_arrow_up.png');
}

.ug-gallery-wrapper .ug-grid-panel .grid-arrow-up.ug-skin-alexis.ug-button-hover{
	background-position:0px -25px;	
}

.ug-gallery-wrapper .ug-grid-panel .grid-arrow-up.ug-skin-alexis.ug-button-hover.ug-button-disabled,
.ug-gallery-wrapper .ug-grid-panel .grid-arrow-up.ug-skin-alexis.ug-button-disabled{
	background-position:0px -50px;
}

/*--- left arrow ---*/

.ug-gallery-wrapper .ug-grid-panel .grid-arrow-left.ug-skin-alexis{
	width:40px;
	height:40px;
	background-position:0px 0px;
	background-image:url('images/grid_arrow_left.png');
}

.ug-gallery-wrapper .ug-grid-panel .grid-arrow-left.ug-skin-alexis.ug-button-hover{
	background-position:0px -40px;
}

.ug-gallery-wrapper .ug-grid-panel .grid-arrow-left.ug-skin-alexis.ug-button-hover.ug-button-disabled,
.ug-gallery-wrapper .ug-grid-panel .grid-arrow-left.ug-skin-alexis.ug-button-disabled{
	background-position:0px -80px;
}

/*--- right arrow ---*/

.ug-gallery-wrapper .ug-grid-panel .grid-arrow-right.ug-skin-alexis{
	width:40px;
	height:40px;
	background-position:0px 0px;	
	background-image:url('images/grid_arrow_right.png');
}

.ug-gallery-wrapper .ug-grid-panel .grid-arrow-right.ug-skin-alexis.ug-button-hover{
	background-position:0px -40px;
}

.ug-gallery-wrapper .ug-grid-panel .grid-arrow-right.ug-skin-alexis.ug-button-hover.ug-button-disabled,
.ug-gallery-wrapper .ug-grid-panel .grid-arrow-right.ug-skin-alexis.ug-button-disabled{
	background-position:0px -80px;
}

/*--- left arrow - horizontal panel type ---*/

.ug-gallery-wrapper .ug-grid-panel .grid-arrow-left-hortype.ug-skin-alexis{
	width:15px;
	height:30px;
	background-image:url('images/grid_arrow_left_hortype.png');
	background-position:0px 0px;
}

.ug-gallery-wrapper .ug-grid-panel .grid-arrow-left-hortype.ug-skin-alexis.ug-button-hover{
	background-position:0px -30px;
}

.ug-gallery-wrapper .ug-grid-panel .grid-arrow-left-hortype.ug-skin-alexis.ug-button-hover.ug-button-disabled,
.ug-gallery-wrapper .ug-grid-panel .grid-arrow-left-hortype.ug-skin-alexis.ug-button-disabled{
	background-position:0px -60px;
}


/*--- right arrow - horizontal panel type ---*/

.ug-gallery-wrapper .ug-grid-panel .grid-arrow-right-hortype.ug-skin-alexis{
	width:15px;
	height:30px;
	background-image:url('images/grid_arrow_right_hortype.png');
	background-position:0px 0px;
}

.ug-gallery-wrapper .ug-grid-panel .grid-arrow-right-hortype.ug-skin-alexis.ug-button-hover{
	background-position:0px -30px;
}

.ug-gallery-wrapper .ug-grid-panel .grid-arrow-right-hortype.ug-skin-alexis.ug-button-hover.ug-button-disabled,
.ug-gallery-wrapper .ug-grid-panel .grid-arrow-right-hortype.ug-skin-alexis.ug-button-disabled{
	background-position:0px -60px;
}


.---------Strip_Panel_Arrows--------{}

/* left and right arrows */

.ug-strip-panel .ug-strip-arrow-left.ug-skin-alexis,
.ug-strip-panel .ug-strip-arrow-right.ug-skin-alexis{
	width:25px;
	height:50px;
}

.ug-strip-panel .ug-strip-arrow-left.ug-skin-alexis .ug-strip-arrow-tip,
.ug-strip-panel .ug-strip-arrow-right.ug-skin-alexis .ug-strip-arrow-tip{
	background-position:0px 0px;
	background-repeat:no-repeat;
	width:4px;
	height:7px;
}

.ug-strip-panel .ug-strip-arrow-left.ug-skin-alexis .ug-strip-arrow-tip{
	background-image:url('images/arrows_strip_left.png');
}

.ug-strip-panel .ug-strip-arrow-right.ug-skin-alexis .ug-strip-arrow-tip{
	background-image:url('images/arrows_strip_right.png');	
}

.ug-strip-panel .ug-strip-arrow-left.ug-skin-alexis.ug-button-hover .ug-strip-arrow-tip,
.ug-strip-panel .ug-strip-arrow-right.ug-skin-alexis.ug-button-hover .ug-strip-arrow-tip{
	background-position:0px -7px;
}


/* up and down arrows */

.ug-strip-panel .ug-strip-arrow-up.ug-skin-alexis,
.ug-strip-panel .ug-strip-arrow-down.ug-skin-alexis{
	height:25px;
	width:50px;
}

.ug-strip-panel .ug-strip-arrow-up.ug-skin-alexis .ug-strip-arrow-tip,
.ug-strip-panel .ug-strip-arrow-down.ug-skin-alexis .ug-strip-arrow-tip{
	background-position:0px 0px;
	background-repeat:no-repeat;
	width:7px;
	height:4px;
}

.ug-strip-panel .ug-strip-arrow-up.ug-skin-alexis .ug-strip-arrow-tip{
	background-image:url('images/arrows_strip_up.png');
}

.ug-strip-panel .ug-strip-arrow-down.ug-skin-alexis .ug-strip-arrow-tip{
	background-image:url('images/arrows_strip_down.png');	
}

.ug-strip-panel .ug-strip-arrow-up.ug-skin-alexis.ug-button-hover .ug-strip-arrow-tip,
.ug-strip-panel .ug-strip-arrow-down.ug-skin-alexis.ug-button-hover .ug-strip-arrow-tip{
	background-position:-7px 0px;
}

.ug-strip-panel .ug-strip-arrow.ug-skin-alexis.ug-button-disabled .ug-strip-arrow-tip{
	background-position:0px 0px;
	opacity:0.5;
	filter: alpha(opacity = 50);
}

.---------Panel_Handle_Tip--------{}

/* left and right handle */
.ug-gallery-wrapper .ug-handle-tip-left.ug-skin-alexis,
.ug-gallery-wrapper .ug-handle-tip-right.ug-skin-alexis{
	width:37px;
	height:40px;
	background-image:url('images/grid_handle_right.png');
	background-repeat:no-repeat;
	background-position:0px 0px;
}

.ug-gallery-wrapper .ug-handle-tip-right.ug-skin-alexis{
	background-image:url('images/grid_handle_left.png');
	background-position:0px 0px;
}

.ug-gallery-wrapper .ug-handle-tip-left.ug-button-hover.ug-skin-alexis,
.ug-gallery-wrapper .ug-handle-tip-right.ug-button-hover.ug-skin-alexis{
	background-position:0px 0px;	
}

.ug-gallery-wrapper .ug-handle-tip-left.ug-skin-alexis.ug-button-closed{
	background-image:url('images/grid_handle_left.png');
	background-position:0px 0px;
}

.ug-gallery-wrapper .ug-handle-tip-right.ug-skin-alexis.ug-button-closed{
	background-image:url('images/grid_handle_right.png');
	background-position:0px 0px;
}

.ug-gallery-wrapper .ug-handle-tip-left.ug-skin-alexis.ug-button-closed.ug-button-hover{
	background-position:0px 0px;
	
}

.ug-gallery-wrapper .ug-handle-tip-right.ug-skin-alexis.ug-button-closed.ug-button-hover{
	background-position:0px 0px;
}


/* top and bottom handle */

.ug-gallery-wrapper .ug-handle-tip-top.ug-skin-alexis,
.ug-gallery-wrapper .ug-handle-tip-bottom.ug-skin-alexis{	
	width:36px;
	height:19px;
	background-image:url('images/grid_handle_up.png');
	background-repeat:no-repeat;
	background-position:-36px 0px;
}

.ug-gallery-wrapper .ug-handle-tip-bottom.ug-skin-alexis{
	background-image:url('images/grid_handle_bottom.png');
	background-position:-36px 0px;
}

.ug-gallery-wrapper .ug-handle-tip-top.ug-skin-alexis.ug-button-hover,
.ug-gallery-wrapper .ug-handle-tip-bottom.ug-skin-alexis.ug-button-hover{
	background-position:0px 0px;	
}

.ug-gallery-wrapper .ug-handle-tip-top.ug-skin-alexis.ug-button-closed,
.ug-gallery-wrapper .ug-handle-tip-bottom.ug-skin-alexis.ug-button-closed{
	background-position:-108px 0px;
}

.ug-gallery-wrapper .ug-handle-tip-top.ug-skin-alexis.ug-button-closed.ug-button-hover,
.ug-gallery-wrapper .ug-handle-tip-bottom.ug-skin-alexis.ug-button-closed.ug-button-hover{
	background-position:-72px 0px;
}

